@@ -5,7 +5,7 @@ import subprocess
 logger = logging.getLogger(__name__)
 
 
-def run(cmd, exit_status = 0, stdout_regexp = None, stderr_regexp = None) -> bool:
+def run(cmd, exit_status = 0, stdout_regexp = None, stderr_regexp = None, **kwargs) -> bool:
     # subprocess.CompletedProcess
     res =  subprocess.run(
         cmd.split(' '), stdout=subprocess.PIPE, stderr=subprocess.PIPE
